@@ -6,7 +6,7 @@ package common
 import (
 	"sync"
 
-	policiesv1 "github.com/open-cluster-management/config-policy-controller/pkg/apis/policy/v1"
+	policiesv1 "github.com/stolostron/config-policy-controller/pkg/apis/policy/v1"
 )
 
 //SyncedPolicyMap a thread safe map
