@@ -7,7 +7,7 @@ import (
 	"reflect"
 	"testing"
 
-	policiesv1 "github.com/open-cluster-management/config-policy-controller/pkg/apis/policy/v1"
+	policiesv1 "github.com/stolostron/config-policy-controller/pkg/apis/policy/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
