@@ -5,10 +5,12 @@ package configurationpolicy
 
 import (
 	"fmt"
+	"reflect"
 	"sort"
 	"strings"
 
-	policyv1 "github.com/open-cluster-management/config-policy-controller/pkg/apis/policy/v1"
+	policyv1 "github.com/stolostron/config-policy-controller/pkg/apis/policy/v1"
+	apiRes "k8s.io/apimachinery/pkg/api/resource"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
@@ -68,12 +70,38 @@ func updateRelatedObjectsStatus(list []policyv1.RelatedObject,
 	return list
 }
 
+//equalObjWithSort is a wrapper function that calls the correct function to check equality depending on what
+//type the objects to compare are
+func equalObjWithSort(mergedObj interface{}, oldObj interface{}) (areEqual bool) {
+	switch mergedObj := mergedObj.(type) {
+	case (map[string]interface{}):
+		if oldObj == nil || !checkFieldsWithSort(mergedObj, oldObj.(map[string]interface{})) {
+			return false
+		}
+	case ([]interface{}):
+		if oldObj == nil || !checkListsMatch(mergedObj, oldObj.([]interface{})) {
+			return false
+		}
+	default:
+		if !reflect.DeepEqual(fmt.Sprint(mergedObj), fmt.Sprint(oldObj)) {
+			return false
+		}
+	}
+	return true
+}
+
+//checFieldsWithSort is a check for maps that uses an arbitrary sort to ensure it is
+//comparing the right values
 func checkFieldsWithSort(mergedObj map[string]interface{}, oldObj map[string]interface{}) (matches bool) {
 	//needed to compare lists, since merge messes up the order
+	if len(mergedObj) < len(oldObj) {
+		return false
+	}
 	match := true
 	for i, mVal := range mergedObj {
 		switch mVal := mVal.(type) {
 		case (map[string]interface{}):
+			//if field is a map, recurse to check for a match
 			oVal, ok := oldObj[i].(map[string]interface{})
 			if !ok {
 				match = false
@@ -82,6 +110,7 @@ func checkFieldsWithSort(mergedObj map[string]interface{}, oldObj map[string]int
 				match = false
 			}
 		case ([]map[string]interface{}):
+			//if field is a list of maps, use checkListFieldsWithSort to check for a match
 			oVal, ok := oldObj[i].([]map[string]interface{})
 			if !ok {
 				match = false
@@ -90,17 +119,12 @@ func checkFieldsWithSort(mergedObj map[string]interface{}, oldObj map[string]int
 				match = false
 			}
 		case ([]interface{}):
+			//if field is a generic list, sort and iterate through them to make sure each value matches
 			oVal, ok := oldObj[i].([]interface{})
 			if !ok {
 				match = false
 				break
 			}
-			sort.Slice(oVal, func(i, j int) bool {
-				return fmt.Sprintf("%v", oVal[i]) < fmt.Sprintf("%v", oVal[j])
-			})
-			sort.Slice(mVal, func(x, y int) bool {
-				return fmt.Sprintf("%v", mVal[x]) < fmt.Sprintf("%v", mVal[y])
-			})
 			if len(mVal) != len(oVal) {
 				match = false
 			} else {
@@ -108,7 +132,28 @@ func checkFieldsWithSort(mergedObj map[string]interface{}, oldObj map[string]int
 					match = false
 				}
 			}
+		case string:
+			//extra check to see if value is a byte value
+			mQty, err := apiRes.ParseQuantity(mVal)
+			if err != nil {
+				//if the value is a regular string, check equality normally
+				oVal := oldObj[i]
+				if fmt.Sprint(oVal) != fmt.Sprint(mVal) {
+					match = false
+				}
+			} else {
+				//if the value is a quantity of bytes, convert original
+				oQty, err := apiRes.ParseQuantity(mVal)
+				if err != nil {
+					match = false
+				} else {
+					if !oQty.Equal(mQty) {
+						match = false
+					}
+				}
+			}
 		default:
+			//if field is not an object, just do a basic compare to check for a match
 			oVal := oldObj[i]
 			if fmt.Sprint(oVal) != fmt.Sprint(mVal) {
 				match = false
@@ -118,6 +163,8 @@ func checkFieldsWithSort(mergedObj map[string]interface{}, oldObj map[string]int
 	return match
 }
 
+//checkListFieldsWithSort is a check for lists of maps that uses an arbitrary sort to ensure it is
+//comparing the right values
 func checkListFieldsWithSort(mergedObj []map[string]interface{}, oldObj []map[string]interface{}) (matches bool) {
 	sort.Slice(oldObj, func(i, j int) bool {
 		return fmt.Sprintf("%v", oldObj[i]) < fmt.Sprintf("%v", oldObj[j])
@@ -133,17 +180,12 @@ func checkListFieldsWithSort(mergedObj []map[string]interface{}, oldObj []map[st
 		for i, mVal := range mergedItem {
 			switch mVal := mVal.(type) {
 			case ([]interface{}):
+				//if a map in the list contains a nested list, sort and check for equality
 				oVal, ok := oldItem[i].([]interface{})
 				if !ok {
 					match = false
 					break
 				}
-				sort.Slice(oVal, func(i, j int) bool {
-					return fmt.Sprintf("%v", oVal[i]) < fmt.Sprintf("%v", oVal[j])
-				})
-				sort.Slice(mVal, func(x, y int) bool {
-					return fmt.Sprintf("%v", mVal[x]) < fmt.Sprintf("%v", mVal[y])
-				})
 				if len(mVal) != len(oVal) {
 					match = false
 				} else {
@@ -152,10 +194,32 @@ func checkListFieldsWithSort(mergedObj []map[string]interface{}, oldObj []map[st
 					}
 				}
 			case (map[string]interface{}):
+				//if a map in the list contains another map, check fields for equality
 				if !checkFieldsWithSort(mVal, oldItem[i].(map[string]interface{})) {
 					match = false
 				}
+			case string:
+				//extra check to see if value is a byte value
+				mQty, err := apiRes.ParseQuantity(mVal)
+				if err != nil {
+					//if the value is a regular string, check equality normally
+					oVal := oldItem[i]
+					if fmt.Sprint(oVal) != fmt.Sprint(mVal) {
+						match = false
+					}
+				} else {
+					//if the value is a quantity of bytes, convert original
+					oQty, err := apiRes.ParseQuantity(mVal)
+					if err != nil {
+						match = false
+					} else {
+						if !oQty.Equal(mQty) {
+							match = false
+						}
+					}
+				}
 			default:
+				//if the field in the map is not an object, just do a generic check
 				oVal := oldItem[i]
 				if fmt.Sprint(oVal) != fmt.Sprint(mVal) {
 					match = false
@@ -166,6 +230,7 @@ func checkListFieldsWithSort(mergedObj []map[string]interface{}, oldObj []map[st
 	return match
 }
 
+//checkListsMatch is a generic list check that uses an arbitrary sort to ensure it is comparing the right values
 func checkListsMatch(oldVal []interface{}, mergedVal []interface{}) (m bool) {
 	oVal := append([]interface{}{}, oldVal...)
 	mVal := append([]interface{}{}, mergedVal...)
@@ -183,8 +248,17 @@ func checkListsMatch(oldVal []interface{}, mergedVal []interface{}) (m bool) {
 		return false
 	}
 	for idx, oNestedVal := range oVal {
-		if fmt.Sprint(oNestedVal) != fmt.Sprint(mVal[idx]) {
-			match = false
+		switch oNestedVal := oNestedVal.(type) {
+		case (map[string]interface{}):
+			//if list contains maps, recurse on those maps to check for a match
+			if !checkFieldsWithSort(mVal[idx].(map[string]interface{}), oNestedVal) {
+				match = false
+			}
+		default:
+			//otherwise, just do a generic check
+			if fmt.Sprint(oNestedVal) != fmt.Sprint(mVal[idx]) {
+				match = false
+			}
 		}
 	}
 	return match
@@ -246,6 +320,41 @@ func formatMetadata(metadata map[string]interface{}) (formatted map[string]inter
 	return md
 }
 
+func fmtMetadataForCompare(metadataTemp map[string]interface{}, metadataExisting map[string]interface{}) (formatted map[string]interface{},
+	formattedExisting map[string]interface{}) {
+	mdTemp := map[string]interface{}{}
+	mdExisting := map[string]interface{}{}
+	if labelsTemp, ok := metadataTemp["labels"]; ok {
+		mdTemp["labels"] = labelsTemp
+		if labelsExisting, ok := metadataExisting["labels"]; ok {
+			mdExisting["labels"] = labelsExisting
+		}
+	}
+	if annosTemp, ok := metadataTemp["annotations"]; ok {
+		noAutogenerated := map[string]interface{}{}
+		for key := range annosTemp.(map[string]interface{}) {
+			if !isAutogenerated(key) {
+				noAutogenerated[key] = annosTemp.(map[string]interface{})[key]
+			}
+		}
+		if len(noAutogenerated) > 0 {
+			mdTemp["annotations"] = noAutogenerated
+		}
+		if annosExisting, ok := metadataExisting["annotations"]; ok {
+			noAutogeneratedExisting := map[string]interface{}{}
+			for key := range annosExisting.(map[string]interface{}) {
+				if !isAutogenerated(key) {
+					noAutogeneratedExisting[key] = annosExisting.(map[string]interface{})[key]
+				}
+			}
+			if len(noAutogenerated) > 0 {
+				mdExisting["annotations"] = noAutogeneratedExisting
+			}
+		}
+	}
+	return mdTemp, mdExisting
+}
+
 // Format name of resource with its namespace (if it has one)
 func createResourceNameStr(names []string, namespace string, namespaced bool) (nameStr string) {
 	sort.Strings(names)
